##  Ignored and Unlinked Fact Sheets
You can ignore a fact sheet if you don't want to link it to any catalog item. The fact sheet is moved to the Ignored tab. If needed, you can link ignored fact sheets to catalog items later.
Ignoring a fact sheet may be relevant if it’s not within the catalog’s scope. For example, the application or IT component is a proprietary product, and you don't expect the catalog to have information about it. This is especially relevant for self-built software. Currently, it is not possible to ignore business capabilities.
Unlinked fact sheets are fact sheets that are yet to be linked or ignored.
